==> lxqt-l10n_0.10.9.orig.tar.xz: lxqt-l10n-0.10.9/lxqt-policykit/lxqt-policykit-agent/lxqt-policykit-agent_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it">
<context>
    <name>LXQtPolicykit::PolicykitAgent</name>
    <message>
        <location filename="../src/policykitagent.cpp" line="71"/>
        <location filename="../src/policykitagent.cpp" line="149"/>
        <source>PolicyKit Information</source>
        <translation>Informazioni PolicyKit</translation>
    </message>
    <message>
        <location filename="../src/policykitagent.cpp" line="71"/>
        <source>Another authentization in progress. Please try it again later.</source>
        <translation>Un&apos;altra autenticazione in corso. Riprova più tardi.</translation>
    </message>
    <message>
        <location filename="../src/policykitagent.cpp" line="132"/>
        <source>Authorization Failed</source>
        <translation>Autorizzazione non riuscita</translation>
    </message>
    <message>
        <location filename="../src/policykitagent.cpp" line="132"/>
        <source>Authorization failed for some reason</source>
        <translation>Autorizzazione non riuscita per alcune ragioni</translation>
    </message>
    <message>
        <location filename="../src/policykitagent.cpp" line="144"/>
        <source>PolicyKit Error</source>
        <translation>Errore di PolicyKit</translation>
    </message>
</context>
<context>
    <name>PolicykitAgentGUI</name>
    <message>
        <location filename="../src/policykitagentgui.ui" line="14"/>
        <source>Authentication Required</source>
        <translation>Autenticazione richiesta</translation>
    </message>
    <message>
        <location filename="../src/policykitagentgui.ui" line="55"/>
        <source>Identity:</source>
        <translation>Identità:</translation>
    </message>
    <message>
        <location filename="../src/policykitagentgui.ui" line="65"/>
        <source>Password:</source>
        <translation>Password:</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-policykit/lxqt-policykit-agent/lxqt-policykit-agent_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>LXQtPolicykit::PolicykitAgent</name>
    <message>
        <location filename="../../../src/policykitagent.cpp" line="71"/>
        <location filename="../../../src/policykitagent.cpp" line="149"/>
        <source>PolicyKit Information</source>
        <translation>Informazioni PolicyKit</translation>
    </message>
    <message>
        <location filename="../../../src/policykitagent.cpp" line="71"/>
        <source>Another authentization in progress. Please try it again later.</source>
        <translation>Un&apos;altra autenticazione in corso. Riprova più tardi.</translation>
    </message>
    <message>
        <location filename="../../../src/policykitagent.cpp" line="132"/>
        <source>Authorization Failed</source>
        <translation>Autorizzazione non riuscita</translation>
    </message>
    <message>
        <location filename="../../../src/policykitagent.cpp" line="132"/>
        <source>Authorization failed for some reason</source>
        <translation>Autorizzazione non riuscita per alcune ragioni</translation>
    </message>
    <message>
        <location filename="../../../src/policykitagent.cpp" line="144"/>
        <source>PolicyKit Error</source>
        <translation>Errore di PolicyKit</translation>
    </message>
</context>
<context>
    <name>PolicykitAgentGUI</name>
    <message>
        <location filename="../../../src/policykitagentgui.ui" line="14"/>
        <source>Authentication Required</source>
        <translation>Autenticazione richiesta</translation>
    </message>
    <message>
        <location filename="../../../src/policykitagentgui.ui" line="55"/>
        <source>Identity:</source>
        <translation>Identità:</translation>
    </message>
    <message>
        <location filename="../../../src/policykitagentgui.ui" line="65"/>
        <source>Password:</source>
        <translation>Password:</translation>
    </message>
</context>
</TS>
